"""
Empty test file
"""

import moat.modbus  # pylint: disable=unused-import


def test_nothing():
    """
    Empty test
    """
    pass
